@@ -178,9 +178,9 @@ void attribute_align_arg mpg123_delete_pars(mpg123_pars* mp)
 
 int attribute_align_arg mpg123_reset_eq(mpg123_handle *mh)
 {
-	int i;
 	if(mh == NULL) return MPG123_BAD_HANDLE;
 #ifndef NO_EQUALIZER
+	int i;
 	mh->have_eq_settings = 0;
 	for(i=0; i < 32; ++i) mh->equalizer[0][i] = mh->equalizer[1][i] = DOUBLE_TO_REAL(1.0);
 #endif
@@ -984,6 +984,12 @@ int attribute_align_arg mpg123_volume_change(mpg123_handle *mh, double change)
 	return mpg123_volume(mh, change + (double) mh->p.outscale);
 }
 
+int attribute_align_arg mpg123_volume_change_db(mpg123_handle *mh, double change)
+{
+	if(mh == NULL) return MPG123_ERR;
+	return mpg123_volume(mh, dbchange(mh->p.outscale, change));
+}
+
 int attribute_align_arg mpg123_volume(mpg123_handle *mh, double vol)
 {
 	if(mh == NULL) return MPG123_ERR;
